==> library1.4.1.tar.bz2: library/utils/photo_functions.php <==
<?php
  ///////////////////////////////////////////////////
  // Блок "Фотогалерея"
  // 2004 (C) IT-студия SoftTime (http://www.softtime.ru)
  // Симдянов И.В. (simdyanov@softtime.ru)
  // Голышев С.В. (softtime@softtime.ru)
  ///////////////////////////////////////////////////

  // Функция создающая уменьшенную копию фотографии $filename,
  // которая помещается в файл $smallimage
  // Уменьшенный вариант имеет ширину и высоту равную
  // $w и $h пикселам, соответственн.
  function resizeimg($filename, $smallimage, $w, $h)
  {
    // Имя файла с масштабируемым изображением
    $filename = $filename;
    // Имя файла с уменьшенной копией.
    $smallimage = $smallimage;

    // получим размеры исходного изображения
    $size_img = getimagesize($filename);

    // создадим пустое изображение по заданным размерам
    $dest_img = imagecreatetruecolor($w, $h);
    
    if($size_img['mime'] =="image/jpeg")
    {
    // создаем jpeg из файла
    $src_img = imagecreatefromjpeg($filename);
    imagecopyresampled($dest_img, $src_img, 0, 0, 0, 0, $w, $h, $size_img[0], $size_img[1]);

    // сохраняем уменьшенную копию в файл 
    imagejpeg($dest_img, $smallimage);
    }
    elseif($size_img['mime'] =="image/png")
    {
    // создаем png из файла
    $src_img = imagecreatefrompng($filename);
    imagecopyresampled($dest_img, $src_img, 0, 0, 0, 0, $w, $h, $size_img[0], $size_img[1]);

    // сохраняем уменьшенную копию в файл 
    imagepng($dest_img,$smallimage);
    }
    elseif($size_img['mime'] =="image/gif")
    {
    // создаем gif из файла
    $src_img = imagecreatefromgif($filename);
    imagecopyresampled($dest_img, $src_img, 0, 0, 0, 0, $w, $h, $size_img[0], $size_img[1]);

    // сохраняем уменьшенную копию в файл 
    imagegif($dest_img, $smallimage);
    }
    if($size_img['mime'] !=="image/gif" && $size_img['mime'] !=="image/png" && $size_img['mime'] !=="image/jpeg") 
    {
    echo"<p align='center'>Внимание! Не поддерживаемый тип файла, используйте для выкладки форматы *.jpeg, *.png или *.gif.</p>";
    if(file_exists($filename)) {unlink($filename);}
    exit();
    }

    // чистим память от созданных изображений
    imagedestroy($dest_img);
    imagedestroy($src_img);
    return true;
  }

  function resizeimg_l_r($filename, $smallimage, $w, $h)
  {
    // Имя файла с масштабируемым изображением
    $filename = $filename;
    // Имя файла с уменьшенной копией.
    $smallimage = $smallimage;
    $mask = imagecreatefrompng("../img/rec_l_r_test.png");

    // получим размеры исходного изображения
    $size_img = getimagesize($filename);

    // создадим пустое изображение по заданным размерам
    $dest_img = imagecreatetruecolor($w, $h);

    if($size_img['mime'] =="image/jpeg")
    {
    // создаем jpeg из файла
    $src_img = imagecreatefromjpeg($filename);
    imagecopyresampled($dest_img, $src_img, 0, 0, 0, 0, $w, $h, $size_img[0], $size_img[1]);
    //imagecopyresized ($dest_img,$src_img, 0,0, 0,0, $w, $h, imagesx($src_img),imagesy($src_img));
    imagecopy ($dest_img, $mask, 0, 0, 0, 0, $w, $h);
    $trans = imagecolorat($dest_img, 1, 1);
    imagecolortransparent($dest_img, $trans);

    // сохраняем уменьшенную копию в файл
    imagejpeg($dest_img, $smallimage);
    }
    elseif($size_img['mime'] =="image/png")
    {
    // создаем png из файла
    $src_img = imagecreatefrompng($filename);
    imagecopyresampled($dest_img, $src_img, 0, 0, 0, 0, $w, $h, $size_img[0], $size_img[1]);
    imagecopy ($dest_img,$mask,0,0,0,0,$w, $h);
    $trans = imagecolorat($dest_img,0,0);
    imagecolortransparent($dest_img,$trans);

    // сохраняем уменьшенную копию в файл
    imagepng($dest_img,$smallimage);
    }
    elseif($size_img['mime'] =="image/gif")
    {
    // создаем gif из файла
    $src_img = imagecreatefromgif($filename);
    imagecopyresampled($dest_img, $src_img, 0, 0, 0, 0, $w, $h, $size_img[0], $size_img[1]);
    imagecopy ($dest_img,$mask,0,0,0,0,$w, $h);
    $trans = imagecolorat($dest_img,1,1);
    imagecolortransparent($dest_img,$trans);

    // сохраняем уменьшенную копию в файл
    imagegif($dest_img, $smallimage);
    }
    if($size_img['mime'] !=="image/gif" && $size_img['mime'] !=="image/png" && $size_img['mime'] !=="image/jpeg")
    {
    echo"<p align='center'>Внимание! Не поддерживаемый тип файла, используйте для выкладки форматы *.jpeg, *.png или *.gif.</p>";
    if(file_exists($filename)) {unlink($filename);}
    exit();
    }

    // чистим память от созданных изображений
    imagedestroy($dest_img);
    imagedestroy($src_img);
    imagedestroy($mask);
    return true;
  }
?>

==> library1.19.1.tar.bz2: library/utils/photo_functions.php <==
<?php
  ///////////////////////////////////////////////////
  // Блок "Фотогалерея"
  // 2004 (C) IT-студия SoftTime (http://www.softtime.ru)
  // Симдянов И.В. (simdyanov@softtime.ru)
  // Голышев С.В. (softtime@softtime.ru)
  ///////////////////////////////////////////////////

  // Функция создающая уменьшенную копию фотографии $filename,
  // которая помещается в файл $smallimage
  // Уменьшенный вариант имеет ширину и высоту равную
  // $w и $h пикселам, соответственн.
  function resizeimg($filename, $smallimage, $w, $h)
  {
    // Имя файла с масштабируемым изображением
    $filename = $filename;
    // Имя файла с уменьшенной копией.
    $smallimage = $smallimage;

    // получим размеры исходного изображения
    $size_img = getimagesize($filename);

    // создадим пустое изображение по заданным размерам
    $dest_img = imagecreatetruecolor($w, $h);
    
    if($size_img['mime'] =="image/jpeg")
    {
    // создаем jpeg из файла
    $src_img = imagecreatefromjpeg($filename);
    imagecopyresampled($dest_img, $src_img, 0, 0, 0, 0, $w, $h, $size_img[0], $size_img[1]);

    // сохраняем уменьшенную копию в файл 
    imagejpeg($dest_img, $smallimage);
    }
    elseif($size_img['mime'] =="image/jpg")
    {
    // создаем jpg из файла
    $src_img = imagecreatefromjpeg($filename);
    imagecopyresampled($dest_img, $src_img, 0, 0, 0, 0, $w, $h, $size_img[0], $size_img[1]);

    // сохраняем уменьшенную копию в файл 
    imagejpeg($dest_img, $smallimage);
    }
    elseif($size_img['mime'] =="image/png")
    {
    // создаем png из файла
    $src_img = imagecreatefrompng($filename);
    imagecopyresampled($dest_img, $src_img, 0, 0, 0, 0, $w, $h, $size_img[0], $size_img[1]);

    // сохраняем уменьшенную копию в файл 
    imagepng($dest_img,$smallimage);
    }
    elseif($size_img['mime'] =="image/gif")
    {
    // создаем gif из файла
    $src_img = imagecreatefromgif($filename);
    imagecopyresampled($dest_img, $src_img, 0, 0, 0, 0, $w, $h, $size_img[0], $size_img[1]);

    // сохраняем уменьшенную копию в файл 
    imagegif($dest_img, $smallimage);
    }
    if($size_img['mime'] !=="image/gif" && $size_img['mime'] !=="image/png" && $size_img['mime'] !=="image/jpeg" && $size_img['mime'] !=="image/jpg") 
    {
    echo"<p align='center'>Внимание! Не поддерживаемый тип файла, используйте для выкладки форматы *.jpg, *.jpeg, *.png или *.gif.<br />Если тип файла верный, посмотрите разрешения на папку library/photo/</p>";
    if(file_exists($filename)) {unlink($filename);}
    exit();
    }

    // чистим память от созданных изображений
    imagedestroy($dest_img);
    imagedestroy($src_img);
    return true;
  }

  function resizeimg_l_r($filename, $smallimage, $w, $h)
  {
    // Имя файла с масштабируемым изображением
    $filename = $filename;
    // Имя файла с уменьшенной копией.
    $smallimage = $smallimage;
    $mask = imagecreatefrompng("../img/rec_l_r_test.png");

    // получим размеры исходного изображения
    $size_img = getimagesize($filename);

    // создадим пустое изображение по заданным размерам
    $dest_img = imagecreatetruecolor($w, $h);

    if($size_img['mime'] =="image/jpeg")
    {
    // создаем jpeg из файла
    $src_img = imagecreatefromjpeg($filename);
    imagecopyresampled($dest_img, $src_img, 0, 0, 0, 0, $w, $h, $size_img[0], $size_img[1]);
    //imagecopyresized ($dest_img,$src_img, 0,0, 0,0, $w, $h, imagesx($src_img),imagesy($src_img));
    imagecopy ($dest_img, $mask, 0, 0, 0, 0, $w, $h);
    $trans = imagecolorat($dest_img, 1, 1);
    imagecolortransparent($dest_img, $trans);

    // сохраняем уменьшенную копию в файл
    imagejpeg($dest_img, $smallimage);
    }
    elseif($size_img['mime'] =="image/jpg")
    {
    // создаем jpeg из файла
    $src_img = imagecreatefromjpeg($filename);
    imagecopyresampled($dest_img, $src_img, 0, 0, 0, 0, $w, $h, $size_img[0], $size_img[1]);
    //imagecopyresized ($dest_img,$src_img, 0,0, 0,0, $w, $h, imagesx($src_img),imagesy($src_img));
    imagecopy ($dest_img, $mask, 0, 0, 0, 0, $w, $h);
    $trans = imagecolorat($dest_img, 1, 1);
    imagecolortransparent($dest_img, $trans);

    // сохраняем уменьшенную копию в файл
    imagejpeg($dest_img, $smallimage);
    }
    elseif($size_img['mime'] =="image/png")
    {
    // создаем png из файла
    $src_img = imagecreatefrompng($filename);
    imagecopyresampled($dest_img, $src_img, 0, 0, 0, 0, $w, $h, $size_img[0], $size_img[1]);
    imagecopy ($dest_img,$mask,0,0,0,0,$w, $h);
    $trans = imagecolorat($dest_img,0,0);
    imagecolortransparent($dest_img,$trans);

    // сохраняем уменьшенную копию в файл
    imagepng($dest_img,$smallimage);
    }
    elseif($size_img['mime'] =="image/gif")
    {
    // создаем gif из файла
    $src_img = imagecreatefromgif($filename);
    imagecopyresampled($dest_img, $src_img, 0, 0, 0, 0, $w, $h, $size_img[0], $size_img[1]);
    imagecopy ($dest_img,$mask,0,0,0,0,$w, $h);
    $trans = imagecolorat($dest_img,1,1);
    imagecolortransparent($dest_img,$trans);

    // сохраняем уменьшенную копию в файл
    imagegif($dest_img, $smallimage);
    }
    if($size_img['mime'] !=="image/gif" && $size_img['mime'] !=="image/png" && $size_img['mime'] !=="image/jpeg" && $size_img['mime'] !=="image/jpg")
    {
    echo"<p align='center'>Внимание! Не поддерживаемый тип файла, используйте для выкладки форматы *.jpg, *.jpeg, *.png или *.gif.<br />Если тип файла верный, посмотрите разрешения на папку library/photo/</p>";
    if(file_exists($filename)) {unlink($filename);}
    exit();
    }

    // чистим память от созданных изображений
    imagedestroy($dest_img);
    imagedestroy($src_img);
    imagedestroy($mask);
    return true;
  }
?>
